@@ -1,11 +1,29 @@
+from typing import List
+import asyncio
 import sys
 import os
 import subprocess
 
-from ovshell import protocol
+from ovshell import api
 
 
-class OpenVarioOSImpl(protocol.OpenVarioOS):
+class OSProcessImpl(api.OSProcess):
+    def __init__(self, proc: asyncio.subprocess.Process) -> None:
+        self._process = proc
+        assert proc.stdout is not None
+        self.stdout = proc.stdout
+        assert proc.stderr is not None
+        self.stderr = proc.stderr
+
+    async def wait(self) -> int:
+        return await self._process.wait()
+
+    async def read_stderr(self) -> bytes:
+        assert self._process.stderr is not None
+        return await self._process.stderr.read()
+
+
+class OpenVarioOSImpl(api.OpenVarioOS):
     def mount_boot(self) -> None:
         subprocess.run(["mount", "/dev/mmcblk0p1", "/boot"], check=True)
 
@@ -18,10 +36,21 @@ class OpenVarioOSImpl(protocol.OpenVarioOS):
             return fname[1:]
         return fname
 
+    async def run(self, command: str, args: List[str]) -> api.OSProcess:
+        proc = await asyncio.create_subprocess_exec(
+            self.path(command),
+            *args,
+            stdout=asyncio.subprocess.PIPE,
+            stderr=asyncio.subprocess.PIPE,
+            limit=200,
+        )
+        return OSProcessImpl(proc)
+
     def sync(self) -> None:
         os.sync()
 
     def shut_down(self) -> None:
+        self.sync()
         subprocess.run(["halt"])
 
     def restart(self) -> None:
