@@ -1,18 +1,19 @@
 from typing import Optional, Sequence, Tuple
 import os
-import re
 import subprocess
 
-from ovshell import protocol
+from ovshell import api
 from ovshell.ui.settings import StaticChoiceSetting
 
+from ovshell_core import rotation
+
 
 class RotationSetting(StaticChoiceSetting):
     title = "Screen rotation"
     config_key = "core.screen_orientation"
     priority = 80
 
-    def __init__(self, shell: protocol.OpenVarioShell):
+    def __init__(self, shell: api.OpenVarioShell):
         self.shell = shell
         super().__init__()
 
@@ -24,37 +25,10 @@ class RotationSetting(StaticChoiceSetting):
         self.shell.settings.set(self.config_key, value, save=True)
 
     def get_choices(self) -> Sequence[Tuple[str, str]]:
-        return [
-            ("0", "Landscape"),
-            ("1", "Portrait (90°)"),
-            ("2", "Landscape (180°)"),
-            ("3", "Portrait (270°)"),
-        ]
+        return rotation.get_rotations()
 
-    def _apply_rotation(self, rotation: str) -> None:
-        ovos = self.shell.os
-
-        uenvconf_fname = ovos.path("//boot/config.uEnv")
-        if not os.path.exists(uenvconf_fname):
-            ovos.mount_boot()
-
-        with open(uenvconf_fname, "r") as f:
-            uenvconf = f.read()
-
-        uenvconf = re.sub(r"rotation=[0-3]", "rotation=" + rotation, uenvconf)
-
-        with open(uenvconf_fname, "w") as f:
-            f.write(uenvconf)
-
-        # For some weird reason 90 degree rotation is inverted for fbcon
-        fbcon_rotmap = {
-            "0": "0",  # normal
-            "1": "3",  # portrait (90)
-            "2": "2",  # landscape (180)
-            "3": "1",  # portrait (270)
-        }
-        with open(ovos.path("//sys/class/graphics/fbcon/rotate_all"), "w") as f:
-            f.write(fbcon_rotmap[rotation])
+    def _apply_rotation(self, new_rotation: str) -> None:
+        rotation.apply_rotation(self.shell.os, new_rotation)
 
 
 class LanguageSetting(StaticChoiceSetting):
@@ -62,7 +36,7 @@ class LanguageSetting(StaticChoiceSetting):
     config_key = "core.language"
     priority = 70
 
-    def __init__(self, shell: protocol.OpenVarioShell):
+    def __init__(self, shell: api.OpenVarioShell):
         self.shell = shell
         super().__init__()
 
@@ -92,7 +66,7 @@ class ConsoleFontSetting(StaticChoiceSetting):
     priority = 50
     config_key = "core.font"
 
-    def __init__(self, shell: protocol.OpenVarioShell):
+    def __init__(self, shell: api.OpenVarioShell):
         self.shell = shell
         super().__init__()
 
@@ -120,7 +94,7 @@ class ScreenBrightnessSetting(StaticChoiceSetting):
     priority = 75
     brightness_fname = "//sys/class/backlight/lcd/brightness"
 
-    def __init__(self, shell: protocol.OpenVarioShell):
+    def __init__(self, shell: api.OpenVarioShell):
         self.shell = shell
         super().__init__()
 
@@ -165,7 +139,7 @@ class AutostartAppSetting(StaticChoiceSetting):
     priority = 68
     config_key = "ovshell.autostart_app"
 
-    def __init__(self, shell: protocol.OpenVarioShell):
+    def __init__(self, shell: api.OpenVarioShell):
         self.shell = shell
         super().__init__()
 
@@ -188,7 +162,7 @@ class AutostartTimeoutSetting(StaticChoiceSetting):
     priority = 67
     config_key = "ovshell.autostart_timeout"
 
-    def __init__(self, shell: protocol.OpenVarioShell):
+    def __init__(self, shell: api.OpenVarioShell):
         self.shell = shell
         super().__init__()
 
@@ -209,6 +183,6 @@ class AutostartTimeoutSetting(StaticChoiceSetting):
         ]
 
 
-def apply_font(os: protocol.OpenVarioOS, font_name: str) -> None:
+def apply_font(os: api.OpenVarioOS, font_name: str) -> None:
     setfont = os.path("//usr/bin/setfont")
     subprocess.run([setfont, font_name], check=True)
